@@ -14,14 +14,24 @@ OC.L10N.register(
     "News" : "Fréttir",
     "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
     "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
+    "Disable this if you run a custom updater such as the Python updater included in the app." : "Gerðu þetta óvirkt ef þú keyrir sérsniðið uppfærsluforrit eins og Python uppærsluforritið sem innifalið er í smáforritinu.",
     "Purge interval" : "Millibil förgunar",
+    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Lágmarksfjöldi sekúndna þar til eydd streymi og möppur eru fjarlægð úr gagnagrunninum; gildi undir 60 sekúndum eru hunsuð.",
     "Maximum read count per feed" : "Hámarkfjöldi lestra á hvert streymi",
+    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Skilgeinir fjölda greina sem hægt er að lesa í hverju fréttastreymi og sem ekki verður eytt við hreinsunarverkefni: ef eldri greinar birtast aftur eftir að hafa verið lesnar, hækkaðu þá þetta gildi; neikvæð gildi eins og -1 slökkva alfarið á þessum eiginleika.",
     "Maximum redirects" : "Hámarks endurbeiningar",
+    "How many redirects the feed fetcher should follow." : "Hversu mörgum endurbeiningum streymissugan á að fylgja.",
     "Feed fetcher timeout" : "Tímamörk streymissugu",
+    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu.",
     "Explore Service URL" : "Skoða slóð á þjónustu (URL)",
+    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ef það er uppgefið, mun slóð þessarar þjónustu verða könnuð fyrir birtingu á streymum sem birtst í streymavafurshlutanum. Til að fara aftur í innbyggða vafurshlutann, skildu þá þetta eftir autt.",
+    "For more information check the wiki." : "Skoðaðu wiki-vefsvæðið til að fá frekari upplýsingar.",
+    "Update interval" : "Uppfærslutíðni",
+    "Interval in seconds in which the feeds will be updated." : "Tími í sekúndum sem líður milli þess sem streymi eru uppfærð.",
     "Saved" : "Vistað",
     "Download" : "Niðurhal",
     "Close" : "Loka",
+    "Subscribe to" : "Gerast áskrifandi að",
     "No articles available" : "Engar greinar tiltækar",
     "No unread articles available" : "Engar ólesnar greinar tiltækar",
     "Open website" : "Opna vefsvæði",
