@@ -14,9 +14,6 @@ OC.L10N.register(
     "Saved" : "Saglabāts",
     "Download" : "Lejupielādēt",
     "Close" : "Aizvērt",
-    "filter" : "filtrs",
-    "Language" : "Valoda",
-    "Subscribe" : "Abonēt",
     "Open website" : "Atvērt vietni",
     "by" : "līdz",
     "from" : "no",
@@ -30,6 +27,7 @@ OC.L10N.register(
     "Refresh" : "Atsvaidzināt",
     "Load next folder" : "Ielādēt nākamo mapi",
     "Load previous folder" : "Ielādēt iepriekšējo mapi",
+    "Subscribe" : "Abonēt",
     "Web address" : "Tīmekļa adrese",
     "Feed exists already!" : "Plūsma jau eksistē!",
     "Folder" : "Mape",
