@@ -1,7 +1,7 @@
 OC.L10N.register(
     "news",
     {
-    "Can not add feed: Exists already" : "Не можам да додадам фид: Веќе постои",
+    "Can not add feed: Exists already" : "Не можам да додадам канал: Веќе постои",
     "Articles without feed" : "Статии без фид",
     "Can not add folder: Exists already" : "Не можам да додадам папка: Веќе постои",
     "News" : "Новости",
@@ -16,7 +16,9 @@ OC.L10N.register(
     "right" : "десно",
     "left" : "лево",
     "Refresh" : "Освежи",
+    "Load next feed" : "Вчитај следен канал",
     "Subscribe" : "Претплата",
+    "Feed exists already!" : "Каналот веќе постои!",
     "Folder" : "Папка",
     "New folder" : "Нова папка",
     "Folder name" : "Име на папка",
@@ -25,10 +27,12 @@ OC.L10N.register(
     "Username" : "Корисничко име",
     "Password" : "Лозинка",
     "Create" : "Создај",
+    "Deleted feed" : "Избришан канал",
     "Rename" : "Преименувај",
     "Mark read" : "Означи како прочитано",
     "Newest first" : "Новите прво",
     "Oldest first" : "Старите прво",
+    "Open feed URL" : "Отвори URL на каналот",
     "Delete" : "Избриши",
     "Dismiss" : "Отфрли",
     "Collapse" : "Собери",
