@@ -16,9 +16,6 @@ OC.L10N.register(
     "Saved" : "Salvat",
     "Download" : "Telecargar",
     "Close" : "Tampar",
-    "filter" : "filtrar",
-    "Language" : "Lenga",
-    "Subscribe" : "S'abonar",
     "No articles available" : "Pas cap d'article disponible",
     "No unread articles available" : "Cap d'article pas legit de disponible",
     "Open website" : "Dobrir lo site web",
@@ -51,6 +48,7 @@ OC.L10N.register(
     "Focus search field" : "Sélectionner lo camp de recherche",
     "Mark current article's feed/folder read" : "Marcar coma legit lo flux / lo repertòri de l'article en cours",
     "How to set up the operating system cron" : "Cossí configurar lo cron del sistèma operatiu",
+    "Subscribe" : "S'abonar",
     "Web address" : "Adreça web",
     "Feed exists already!" : "Lo flux existís ja !",
     "Folder" : "Dorsièr",
