@@ -14,9 +14,6 @@ OC.L10N.register(
     "Saved" : "Salvat",
     "Download" : "Descarcă",
     "Close" : "Închide",
-    "filter" : "filtru",
-    "Language" : "Limbă",
-    "Subscribe" : "Abonare",
     "No articles available" : "Niciun articol disponibil",
     "No unread articles available" : "Niciun articol necitit disponibil",
     "Open website" : "Deschide website",
@@ -27,6 +24,7 @@ OC.L10N.register(
     "right" : "dreapta",
     "left" : "stânga",
     "Refresh" : "Împrospătare",
+    "Subscribe" : "Abonare",
     "Web address" : "Adresă web",
     "Feed exists already!" : "Fluxul există deja!",
     "Folder" : "Director",
