@@ -4,7 +4,7 @@ OC.L10N.register(
     "Request failed, network connection unavailable!" : "Zahteva je spodletela. Omrežna povezava trenutno ni na voljo!",
     "Request unauthorized. Are you logged in?" : "Zahteva ni ustrezno overjena. Ali ste prijavljeni?",
     "Request forbidden. Are you an admin?" : "Zahteva je zavrnjena. Ali ste prijavljeni kot skrbnik?",
-    "Token expired or app not enabled! Reload the page!" : "Žeton je potekel ali pa program ni omogočen! Poskusite osvežiti stran!",
+    "Token expired or app not enabled! Reload the page!" : "Žeton je pretekel ali pa program ni omogočen! Poskusite osvežiti stran!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Notranja napaka strežnika! Preverite datoteko data/nextcloud.log za podrobnosti!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva je spodletela! Okolje Nextcloud je trenutno v vzdrževalnem načinu!",
     "Can not add feed: Unable to parse feed" : "Vira ni mogoče dodati: podatkov ni mogoče razčleniti",
@@ -17,8 +17,13 @@ OC.L10N.register(
     "Purge interval" : "Časovni razmik odstranjevanja",
     "Maximum read count per feed" : "Največje število prikazanih virov",
     "Maximum redirects" : "Največje število preusmeritev",
+    "How many redirects the feed fetcher should follow." : "Koliko preusmeritvam naj sledi bralnik virov",
     "Feed fetcher timeout" : "Čas nalaganja vira",
+    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Čas, namenjen nalaganju virov RSS in Atom. Če traja dlje je nalaganje virov prekinjeno.",
     "Explore Service URL" : "Razišči spletni naslov storitve",
+    "For more information check the wiki." : "Za več podrobnosti obiščite Wiki",
+    "Update interval" : "Razmik posodobitev",
+    "Interval in seconds in which the feeds will be updated." : "Časovni zamik v sekundah za posodabljanje spletnih virov.",
     "Saved" : "Shranjeno",
     "Download" : "Prejmi",
     "Close" : "Zapri",
@@ -53,9 +58,9 @@ OC.L10N.register(
     "Scroll to active navigation entry" : "Pomakni se na predmet v žarišču",
     "Focus search field" : "Postavi iskalno polje v žarišče",
     "Mark current article's feed/folder read" : "Označi trenutni vir kot prebran",
-    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zaznan je način Ajax oziroma webcron! Izbrani viri ne bodo posodobljeni!",
-    "How to set up the operating system cron" : "Kako nastaviti opravila cron operacijskega sistema",
-    "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti in nastavi hitrejši vzporedni posodabljalnik, ki za posodobitev uporablja  API programa  News",
+    "Ajax or webcron mode detected! Your feeds will not be updated!" : "V uporabi je ali način Ajax ali pa webcron, kar pomeni, da izbrani viri ne bodo posodobljeni!",
+    "How to set up the operating system cron" : "Oglejte si navodila, kako nastaviti opravila cron operacijskega sistema. ↗",
+    "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti je mogoče vzporedni posodabljalnik, ki uporablja vmesnik API programa News ↗.",
     "Subscribe" : "Naročilo",
     "Web address" : "Spletni naslov",
     "Feed exists already!" : "Vir že obstaja!",
