@@ -88,7 +88,7 @@ OC.L10N.register(
     "Unread updated" : "Markera som oläst",
     "Ignore updated" : "Ignorera uppdaterad",
     "Open feed URL" : "Öppna flödeswebbadress",
-    "Delete" : "Radera",
+    "Delete" : "Ta bort",
     "Dismiss" : "Avfärda",
     "Collapse" : "Dölj",
     "Deleted folder" : "Raderad mapp",
@@ -110,7 +110,7 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Olästa/Stjärnmärkta artiklar",
     "Error when importing: file does not contain valid JSON" : "Fel vid import: filen innehåller inte giltig JSON",
     "Help" : "Hjälp",
-    "Keyboard shortcuts" : "Kortkommandon",
+    "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Documentation" : "Dokumentation",
     "Report a bug" : "Rapportera ett problem"
 },
