@@ -16,9 +16,6 @@ OC.L10N.register(
     "Saved" : "Збереженно",
     "Download" : "Завантажити",
     "Close" : "Закрити",
-    "filter" : "фільтр",
-    "Language" : "Мова",
-    "Subscribe" : "Підписатися",
     "No articles available" : "Немає доступних статей",
     "No unread articles available" : "Немає непрочитаних записів",
     "Open website" : "Відкрити веб-сайт",
@@ -51,6 +48,7 @@ OC.L10N.register(
     "Focus search field" : "Поставити курсор у поле пошуку",
     "Mark current article's feed/folder read" : "Зробити поточну подачу/теку артиклю лише для читання",
     "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
+    "Subscribe" : "Підписатися",
     "Web address" : "Веб адреса",
     "Feed exists already!" : "Стрічка вже існує !",
     "Folder" : "Папка",
