@@ -15,33 +15,41 @@
 
 namespace OCA\News\Controller;
 
+use Exception;
 use OCA\News\Service\Exceptions\ServiceConflictException;
 use OCA\News\Service\Exceptions\ServiceNotFoundException;
-use OCA\News\Utility\PsrLogger;
+use OCA\News\Service\FeedServiceV2;
 use OCP\AppFramework\Http\JSONResponse;
 use \OCP\IRequest;
-use \OCP\ILogger;
 use \OCP\IUserSession;
 use \OCP\AppFramework\Http;
 
 use \OCA\News\Service\FeedService;
 use \OCA\News\Service\ItemService;
 use Psr\Log\LoggerInterface;
+use function GuzzleHttp\Psr7\uri_for;
 
 class FeedApiController extends ApiController
 {
-    use JSONHttpErrorTrait;
+    use JSONHttpErrorTrait, ApiPayloadTrait;
 
     /**
+     * TODO: Remove
      * @var ItemService
      */
-    private $itemService;
+    private $oldItemService;
 
     /**
-     * @var FeedService
+     * @var FeedServiceV2
      */
     private $feedService;
 
+    /**
+     * TODO: Remove
+     * @var FeedService
+     */
+    private $oldFeedService;
+
     /**
      * @var LoggerInterface
      */
@@ -56,15 +64,16 @@ class FeedApiController extends ApiController
         string $appName,
         IRequest $request,
         IUserSession $userSession,
-        FeedService $feedService,
-        ItemService $itemService,
+        FeedService $oldFeedService,
+        FeedServiceV2 $feedService,
+        ItemService $oldItemService,
         LoggerInterface $logger
     ) {
         parent::__construct($appName, $request, $userSession);
         $this->feedService = $feedService;
-        $this->itemService = $itemService;
+        $this->oldFeedService = $oldFeedService;
+        $this->oldItemService = $oldItemService;
         $this->logger = $logger;
-        $this->serializer = new EntityApiSerializer('feeds');
     }
 
 
@@ -77,20 +86,17 @@ class FeedApiController extends ApiController
     {
 
         $result = [
-            'starredCount' => $this->itemService->starredCount($this->getUserId()),
-            'feeds' => $this->feedService->findAllForUser($this->getUserId())
+            'starredCount' => $this->oldItemService->starredCount($this->getUserId()),
+            'feeds' => $this->serialize($this->feedService->findAllForUser($this->getUserId()))
         ];
 
-
         try {
-            $result['newestItemId'] =
-                $this->itemService->getNewestItemId($this->getUserId());
-
-            // in case there are no items, ignore
+            $result['newestItemId'] = $this->oldItemService->getNewestItemId($this->getUserId());
         } catch (ServiceNotFoundException $ex) {
+            // in case there are no items, ignore
         }
 
-        return $this->serializer->serialize($result);
+        return $result;
     }
 
 
@@ -99,28 +105,30 @@ class FeedApiController extends ApiController
      * @NoCSRFRequired
      * @CORS
      *
-     * @param string $url
-     * @param int    $folderId
+     * @param string   $url
+     * @param int|null $folderId
      *
      * @return array|mixed|JSONResponse
      */
-    public function create(string $url, int $folderId = 0)
+    public function create(string $url, ?int $folderId = null)
     {
-        try {
-            $this->feedService->purgeDeleted($this->getUserId(), false);
+        if ($folderId === 0) {
+            $folderId = null;
+        }
 
-            $feed = $this->feedService->create($url, $folderId, $this->getUserId());
-            $result = ['feeds' => [$feed]];
+        try {
+            $this->feedService->purgeDeleted();
+
+            $feed = $this->feedService->create($this->getUserId(), $url, $folderId);
+            $result = ['feeds' => $this->serialize($feed)];
 
             try {
-                $result['newestItemId'] =
-                    $this->itemService->getNewestItemId($this->getUserId());
-
-                // in case there are no items, ignore
+                $result['newestItemId'] = $this->oldItemService->getNewestItemId($this->getUserId());
             } catch (ServiceNotFoundException $ex) {
+                // in case there are no items, ignore
             }
 
-            return $this->serializer->serialize($result);
+            return $result;
         } catch (ServiceConflictException $ex) {
             return $this->error($ex, Http::STATUS_CONFLICT);
         } catch (ServiceNotFoundException $ex) {
@@ -141,7 +149,7 @@ class FeedApiController extends ApiController
     public function delete(int $feedId)
     {
         try {
-            $this->feedService->delete($feedId, $this->getUserId());
+            $this->feedService->delete($this->getUserId(), $feedId);
         } catch (ServiceNotFoundException $ex) {
             return $this->error($ex, Http::STATUS_NOT_FOUND);
         }
@@ -160,7 +168,7 @@ class FeedApiController extends ApiController
      */
     public function read(int $feedId, int $newestItemId): void
     {
-        $this->itemService->readFeed($feedId, $newestItemId, $this->getUserId());
+        $this->oldItemService->readFeed($feedId, $newestItemId, $this->getUserId());
     }
 
 
@@ -169,15 +177,19 @@ class FeedApiController extends ApiController
      * @NoCSRFRequired
      * @CORS
      *
-     * @param int $feedId
-     * @param int $folderId
+     * @param int      $feedId
+     * @param int|null $folderId
      *
      * @return array|JSONResponse
      */
-    public function move(int $feedId, int $folderId)
+    public function move(int $feedId, ?int $folderId)
     {
+        if ($folderId === 0) {
+            $folderId = null;
+        }
+
         try {
-            $this->feedService->patch(
+            $this->oldFeedService->patch(
                 $feedId,
                 $this->getUserId(),
                 ['folderId' => $folderId]
@@ -203,7 +215,7 @@ class FeedApiController extends ApiController
     public function rename(int $feedId, string $feedTitle)
     {
         try {
-            $this->feedService->patch(
+            $this->oldFeedService->patch(
                 $feedId,
                 $this->getUserId(),
                 ['title' => $feedTitle]
@@ -222,7 +234,7 @@ class FeedApiController extends ApiController
      */
     public function fromAllUsers(): array
     {
-        $feeds = $this->feedService->findAllFromAllUsers();
+        $feeds = $this->feedService->findAll();
         $result = ['feeds' => []];
 
         foreach ($feeds as $feed) {
@@ -245,9 +257,10 @@ class FeedApiController extends ApiController
     public function update(string $userId, int $feedId): void
     {
         try {
-            $this->feedService->update($userId, $feedId);
+            $feed = $this->feedService->find($userId, $feedId);
+            $this->feedService->fetch($feed);
             // ignore update failure
-        } catch (\Exception $ex) {
+        } catch (Exception $ex) {
             $this->logger->debug('Could not update feed ' . $ex->getMessage());
         }
     }
