@@ -23,47 +23,27 @@ use \OCP\AppFramework\Http;
 
 class UserApiController extends ApiController
 {
-
-    private $rootFolder;
-
     public function __construct(
         string $appName,
         IRequest $request,
-        IUserSession $userSession,
-        IRootFolder $rootFolder
+        IUserSession $userSession
     ) {
         parent::__construct($appName, $request, $userSession);
-        $this->rootFolder = $rootFolder;
     }
 
     /**
      * @NoAdminRequired
      * @NoCSRFRequired
      * @CORS
+     *
+     * @deprecated Should use https://docs.nextcloud.com/server/latest/developer_manual/client_apis/OCS/ocs-api-overview.html#user-metadata
+     *             and avatar is `https://nc.url/avatar/{userid}/{size}?v={1|2}`
      */
     public function index(): array
     {
         $user = $this->getUser();
-
-        // find the avatar
-        $jpgAvatar = '/' . $user->getUID() . '/avatar.jpg';
-        $pngAvatar = '/' . $user->getUID() . '/avatar.png';
         $avatar = null;
 
-        if ($this->rootFolder->nodeExists($jpgAvatar)) {
-            $file = $this->rootFolder->get($jpgAvatar);
-            $avatar = [
-                'data' => base64_encode($file->getContent()),
-                'mime' =>  'image/jpeg'
-            ];
-        } elseif ($this->rootFolder->nodeExists($pngAvatar)) {
-            $file = $this->rootFolder->get($pngAvatar);
-            $avatar = [
-                'data' => base64_encode($file->getContent()),
-                'mime' =>  'image/png'
-            ];
-        }
-
         return [
             'userId' => $user->getUID(),
             'displayName' => $user->getDisplayName(),
