@@ -41,6 +41,7 @@ class FolderMapperV2 extends NewsMapperV2
      * Find all feeds for a user.
      *
      * @param string $userId The user identifier
+     * @param array  $params Filter parameters
      *
      * @return Entity[]
      */
@@ -50,7 +51,7 @@ class FolderMapperV2 extends NewsMapperV2
         $builder->select('*')
                 ->from($this->tableName)
                 ->where('user_id = :user_id')
-                ->where('deleted_at = 0')
+                ->andWhere('deleted_at = 0')
                 ->setParameter(':user_id', $userId);
 
         return $this->findEntities($builder);
@@ -77,8 +78,8 @@ class FolderMapperV2 extends NewsMapperV2
         $builder->select('*')
             ->from($this->tableName)
             ->where('user_id = :user_id')
-            ->where('id = :id')
-            ->where('deleted_at = 0')
+            ->andWhere('id = :id')
+            ->andWhere('deleted_at = 0')
             ->setParameter(':user_id', $userId)
             ->setParameter(':id', $id);
 
